@@ -10,15 +10,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.core.urlresolvers import reverse
-from django import http
-from mox3.mox import IsA  # noqa
+from django.urls import reverse
 from oslo_serialization import jsonutils
 
 from openstack_dashboard import api as os_api
 
 from sahara_dashboard import api
 from sahara_dashboard.test import helpers as test
+from sahara_dashboard.test.helpers import IsHttpRequest
 
 
 INDEX_URL = reverse('horizon:project:data_processing.clusters:clusters-tab')
@@ -27,47 +26,47 @@ DETAILS_URL = reverse(
 
 
 class DataProcessingClusterTests(test.TestCase):
-    @test.create_stubs({api.sahara: ('cluster_template_list',
+
+    @test.create_mocks({api.sahara: ('cluster_template_list',
                                      'image_list',
                                      'cluster_list',
                                      'nodegroup_template_list')})
     def test_index(self):
-        api.sahara.cluster_list(IsA(http.HttpRequest), {}) \
-            .AndReturn(self.clusters.list())
-        self.mox.ReplayAll()
+        self.mock_cluster_list.return_value = self.clusters.list()
         res = self.client.get(INDEX_URL)
+        self.mock_cluster_list.assert_called_once_with(IsHttpRequest(), {})
         self.assertTemplateUsed(res, 'clusters/index.html')
         self.assertContains(res, 'Clusters')
         self.assertContains(res, 'Name')
 
-    @test.create_stubs({api.sahara: ('cluster_template_list', 'image_list',
+    @test.create_mocks({api.sahara: ('cluster_template_list', 'image_list',
                                      'plugin_get_version_details'),
                         os_api.neutron: ('network_list',),
                         os_api.nova: ('keypair_list',)})
     def test_launch_cluster_get_nodata(self):
-        api.sahara.cluster_template_list(IsA(http.HttpRequest)) \
-            .AndReturn([])
-        api.sahara.image_list(IsA(http.HttpRequest)) \
-            .AndReturn([])
-        self.mox.ReplayAll()
+        self.mock_cluster_template_list.return_value = []
+        self.mock_image_list.return_value = []
         url = reverse(
             'horizon:project:data_processing.clusters:configure-cluster')
         res = self.client.get("%s?plugin_name=shoes&hadoop_version=1.1" % url)
+        self.mock_cluster_template_list.assert_called_once_with(
+            IsHttpRequest())
+        self.mock_image_list.assert_called_once_with(IsHttpRequest())
         self.assertContains(res, "No Images Available")
         self.assertContains(res, "No Templates Available")
 
-    @test.create_stubs({api.sahara: ('cluster_get',)})
+    @test.create_mocks({api.sahara: ('cluster_get',)})
     def test_event_log_tab(self):
         cluster = self.clusters.list()[-1]
-        api.sahara.cluster_get(IsA(http.HttpRequest),
-                               "cl2", show_progress=True).AndReturn(cluster)
-        self.mox.ReplayAll()
+        self.mock_cluster_get.return_value = cluster
 
         url = reverse(
             'horizon:project:data_processing.clusters:events', args=["cl2"])
         res = self.client.get(url)
         data = jsonutils.loads(res.content)
 
+        self.mock_cluster_get.assert_called_once_with(
+            IsHttpRequest(), "cl2", show_progress=True)
         self.assertIn("provision_steps", data)
         self.assertEqual(data["need_update"], False)
 
@@ -81,12 +80,10 @@ class DataProcessingClusterTests(test.TestCase):
         self.assertEqual(3, step_1["completed"])
         self.assertEqual(0, len(step_1["events"]))
 
-    @test.create_stubs({api.sahara: ('cluster_get', )})
+    @test.create_mocks({api.sahara: ('cluster_get', )})
     def test_health_checks_tab_sc1(self):
         cluster = self.clusters.list()[-1]
-        api.sahara.cluster_get(IsA(http.HttpRequest),
-                               "cl2").AndReturn(cluster)
-        self.mox.ReplayAll()
+        self.mock_cluster_get.return_value = cluster
 
         url = reverse(
             'horizon:project:data_processing.clusters:verifications',
@@ -94,6 +91,8 @@ class DataProcessingClusterTests(test.TestCase):
         res = self.client.get(url)
         data = jsonutils.loads(res.content)
 
+        self.mock_cluster_get.assert_called_once_with(
+            IsHttpRequest(), "cl2")
         self.assertFalse(data['need_update'])
         check0 = data['checks'][0]
         check1 = data['checks'][1]
@@ -104,13 +103,11 @@ class DataProcessingClusterTests(test.TestCase):
         self.assertEqual('RED', check1['status'])
         self.assertEqual('0:07:40', check0['duration'])
 
-    @test.create_stubs({api.sahara: ('cluster_get', )})
+    @test.create_mocks({api.sahara: ('cluster_get', )})
     def test_health_checks_tab_sc2(self):
         cluster = self.clusters.list()[0]
         cl1_id = 'ec9a0d28-5cfb-4028-a0b5-40afe23f1533'
-        api.sahara.cluster_get(IsA(http.HttpRequest),
-                               cl1_id).AndReturn(cluster)
-        self.mox.ReplayAll()
+        self.mock_cluster_get.return_value = cluster
 
         url = reverse(
             'horizon:project:data_processing.clusters:verifications',
@@ -118,6 +115,8 @@ class DataProcessingClusterTests(test.TestCase):
         res = self.client.get(url)
         data = jsonutils.loads(res.content)
 
+        self.mock_cluster_get.assert_called_once_with(
+            IsHttpRequest(), cl1_id)
         self.assertTrue(data['need_update'])
         check0 = data['checks'][0]
         check1 = data['checks'][1]
@@ -128,18 +127,20 @@ class DataProcessingClusterTests(test.TestCase):
         self.assertEqual('RED', check1['status'])
         self.assertEqual('Houston, we have a problem', check1['description'])
 
-    @test.create_stubs({api.sahara: ('cluster_list',
+    @test.create_mocks({api.sahara: ('cluster_list',
                                      'cluster_delete')})
     def test_delete(self):
         cluster = self.clusters.first()
-        api.sahara.cluster_list(IsA(http.HttpRequest), {}) \
-            .AndReturn(self.clusters.list())
-        api.sahara.cluster_delete(IsA(http.HttpRequest), cluster.id)
-        self.mox.ReplayAll()
+        self.mock_cluster_list.return_value = self.clusters.list()
+        self.mock_cluster_delete.return_value = None
 
         form_data = {'action': 'clusters__delete__%s' % cluster.id}
         res = self.client.post(INDEX_URL, form_data)
 
+        self.mock_cluster_list.assert_called_once_with(
+            IsHttpRequest(), {})
+        self.mock_cluster_delete.assert_called_once_with(
+            IsHttpRequest(), cluster.id)
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, INDEX_URL)
         self.assertMessageCount(success=1)
